@@ -65,9 +65,9 @@ if (!MiscMetabar:::is_vsearch_installed()) {
     )
     expect_s4_class(chimera_fungi$non_chimera, "AAStringSet")
 
-    expect_true(length(chimera_fungi$non_chimera) %in% c(1051, 1088))
-    expect_true(length(chimera_fungi$chimera) %in% c(220, 242))
-    expect_true(length(chimera_fungi$borderline) %in% c(112, 127))
+    expect_true(length(chimera_fungi$non_chimera) %in% c(1051, 1088, 1054))
+    expect_true(length(chimera_fungi$chimera) %in% c(220, 242, 240))
+    expect_true(length(chimera_fungi$borderline) %in% c(112, 127, 126))
   })
 
   test_that("chimera_detection_vs works fine", {
@@ -77,25 +77,25 @@ if (!MiscMetabar:::is_vsearch_installed()) {
       "phyloseq"
     )
 
-    expect_true(ntaxa(data_fungi_nochim) %in% c(1178, 1200))
+    expect_true(ntaxa(data_fungi_nochim) %in% c(1178, 1200, 1180))
     expect_s4_class(
       data_fungi_nochim_16 <- chimera_removal_vs(data_fungi, abskew = 16, min_seq_length = 10),
       "phyloseq"
     )
-    expect_true(ntaxa(data_fungi_nochim_16) %in% c(1259, 1288))
+    expect_true(ntaxa(data_fungi_nochim_16) %in% c(1259, 1288, 1261))
     expect_s4_class(
       data_fungi_nochim2 <-
         chimera_removal_vs(data_fungi, type = "Select_only_non_chim"),
       "phyloseq"
     )
-    expect_true(ntaxa(data_fungi_nochim2) %in% c(1051, 1088))
+    expect_true(ntaxa(data_fungi_nochim2) %in% c(1051, 1088, 1054))
 
     expect_s4_class(
       data_fungi_chimera <-
         chimera_removal_vs(data_fungi, type = "Select_only_chim"),
       "phyloseq"
     )
-    expect_true(ntaxa(data_fungi_chimera) %in% c(220, 242))
+    expect_true(ntaxa(data_fungi_chimera) %in% c(220, 242, 240))
   })
 
 
